==> zio-aws-securityhub_2.13-5.17.124.2-sources.jar: zio/aws/securityhub/model/MapFilterComparison.scala <==
package zio.aws.securityhub.model
import scala.jdk.CollectionConverters._
sealed trait MapFilterComparison {
  def unwrap
      : software.amazon.awssdk.services.securityhub.model.MapFilterComparison
}
object MapFilterComparison {
  def wrap(
      value: software.amazon.awssdk.services.securityhub.model.MapFilterComparison
  ): zio.aws.securityhub.model.MapFilterComparison = value match {
    case software.amazon.awssdk.services.securityhub.model.MapFilterComparison.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.securityhub.model.MapFilterComparison.EQUALS =>
      val r = EQUALS
      r
    case software.amazon.awssdk.services.securityhub.model.MapFilterComparison.NOT_EQUALS =>
      val r = NOT_EQUALS
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.securityhub.model.MapFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.MapFilterComparison =
      software.amazon.awssdk.services.securityhub.model.MapFilterComparison.UNKNOWN_TO_SDK_VERSION
  }
  case object EQUALS extends zio.aws.securityhub.model.MapFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.MapFilterComparison =
      software.amazon.awssdk.services.securityhub.model.MapFilterComparison.EQUALS
  }
  case object NOT_EQUALS extends zio.aws.securityhub.model.MapFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.MapFilterComparison =
      software.amazon.awssdk.services.securityhub.model.MapFilterComparison.NOT_EQUALS
  }
}

==> zio-aws-securityhub_2.13-7.21.15.1-sources.jar: zio/aws/securityhub/model/MapFilterComparison.scala <==
package zio.aws.securityhub.model
import scala.jdk.CollectionConverters._
sealed trait MapFilterComparison {
  def unwrap
      : software.amazon.awssdk.services.securityhub.model.MapFilterComparison
}
object MapFilterComparison {
  def wrap(
      value: software.amazon.awssdk.services.securityhub.model.MapFilterComparison
  ): zio.aws.securityhub.model.MapFilterComparison = value match {
    case software.amazon.awssdk.services.securityhub.model.MapFilterComparison.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.securityhub.model.MapFilterComparison.EQUALS =>
      val r = EQUALS
      r
    case software.amazon.awssdk.services.securityhub.model.MapFilterComparison.NOT_EQUALS =>
      val r = NOT_EQUALS
      r
    case software.amazon.awssdk.services.securityhub.model.MapFilterComparison.CONTAINS =>
      val r = CONTAINS
      r
    case software.amazon.awssdk.services.securityhub.model.MapFilterComparison.NOT_CONTAINS =>
      val r = NOT_CONTAINS
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.securityhub.model.MapFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.MapFilterComparison =
      software.amazon.awssdk.services.securityhub.model.MapFilterComparison.UNKNOWN_TO_SDK_VERSION
  }
  case object EQUALS extends zio.aws.securityhub.model.MapFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.MapFilterComparison =
      software.amazon.awssdk.services.securityhub.model.MapFilterComparison.EQUALS
  }
  case object NOT_EQUALS extends zio.aws.securityhub.model.MapFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.MapFilterComparison =
      software.amazon.awssdk.services.securityhub.model.MapFilterComparison.NOT_EQUALS
  }
  case object CONTAINS extends zio.aws.securityhub.model.MapFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.MapFilterComparison =
      software.amazon.awssdk.services.securityhub.model.MapFilterComparison.CONTAINS
  }
  case object NOT_CONTAINS
      extends zio.aws.securityhub.model.MapFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.MapFilterComparison =
      software.amazon.awssdk.services.securityhub.model.MapFilterComparison.NOT_CONTAINS
  }
}
